@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 //#include <exo/exo.h>
 #include <libxfce4panel/libxfce4panel.h>
-#include <libindicator/indicator-object.h>
+#include <libayatana-indicator/indicator-object.h>
 
 #include "indicator-box.h"
 #include "indicator-button.h"
@@ -185,7 +185,7 @@ xfce_indicator_box_sort_buttons (gconstpointer a,
 
   /* special case for Application indicators (unreliable ordering) */
   /* always compare by name and ignore location field */
-  if (a_io != NULL && g_strcmp0 (a_io, LIBSO("application")) == 0)
+  if (a_io != NULL && g_strcmp0 (a_io, LIBSO("ayatana-application")) == 0)
     result = g_strcmp0 (xfce_indicator_button_get_entry(a0)->name_hint,
                         xfce_indicator_button_get_entry(b0)->name_hint);
 
@@ -224,7 +224,7 @@ xfce_indicator_box_add (GtkContainer *container,
   io_name = xfce_indicator_button_get_io_name (button);
   li = g_hash_table_lookup (box->children, io_name);
   // printf ("   +++ %s %s\n", io_name, xfce_indicator_button_get_entry (button)->name_hint);
-  if (g_strcmp0 (io_name, LIBSO("application")) != 0 &&
+  if (g_strcmp0 (io_name, LIBSO("ayatana-application")) != 0 &&
       xfce_indicator_button_get_pos (button) == 0)
     li = g_list_append (li, button);
   else
@@ -315,6 +315,7 @@ xfce_indicator_box_get_preferred_length (GtkWidget *widget,
   GtkRequisition       child_req;
   GList               *known_indicators, *li, *li_int, *li_tmp;
   gint                 panel_size, size;
+  gboolean             single_row, square_icons;
   gint                 length;
   gint                 row;
   gint                 nrows;
@@ -338,10 +339,20 @@ xfce_indicator_box_get_preferred_length (GtkWidget *widget,
   border_thickness = MAX (padding.left+padding.right+border.left+border.right,
                           padding.top+padding.bottom+border.top+border.bottom);
 
-  size = ICON_SIZE + border_thickness;
   panel_size = indicator_config_get_panel_size (box->config);
-  nrows = MAX (1, panel_size / size);
-  allow_small = !((nrows == 1) || indicator_config_get_single_row (box->config));
+  single_row = indicator_config_get_single_row (box->config);
+  square_icons = indicator_config_get_square_icons (box->config);
+  if (square_icons)
+    {
+      nrows = indicator_config_get_nrows (box->config);
+      size = (panel_size - border_thickness) / (single_row ? 1 : nrows);
+    }
+  else
+    {
+      size = MIN (ICON_SIZE + border_thickness, panel_size);
+      nrows = MAX (1, panel_size / size);
+    }
+  allow_small = !((nrows == 1) || single_row);
 
   panel_orientation = indicator_config_get_panel_orientation (box->config);
 
@@ -375,6 +386,8 @@ xfce_indicator_box_get_preferred_length (GtkWidget *widget,
 
           length =
             MAX (length, (panel_orientation == GTK_ORIENTATION_HORIZONTAL) ? child_req.width :child_req.height);
+          if (square_icons)
+            length = MAX (length, size);
 
           if (row >= nrows || !is_small)
             {
@@ -460,6 +473,7 @@ xfce_indicator_box_size_allocate (GtkWidget     *widget,
   GtkAllocation        child_alloc;
   GtkRequisition       child_req;
   gint                 panel_size, size, full_size;
+  gboolean             single_row, square_icons;
   gint                 x, y;
   gint                 x0, y0;
   GList               *known_indicators, *li, *li_int, *li_tmp;
@@ -495,11 +509,21 @@ xfce_indicator_box_size_allocate (GtkWidget     *widget,
                           padding.top+padding.bottom+border.top+border.bottom);
 
   panel_size = indicator_config_get_panel_size (box->config);
-  size = MIN (ICON_SIZE + border_thickness, panel_size);
-  nrows = panel_size / size;
+  single_row = indicator_config_get_single_row (box->config);
+  square_icons = indicator_config_get_square_icons (box->config);
+  if (square_icons)
+    {
+      nrows = indicator_config_get_nrows (box->config);
+      size = (panel_size - border_thickness) / (single_row ? 1 : nrows);
+    }
+  else
+    {
+      size = MIN (ICON_SIZE + border_thickness, panel_size);
+      nrows = MAX (1, panel_size / size);
+    }
   //full_size = ((nrows-1)*panel_size + nrows*size) / nrows; // regular pitch, margins
   full_size = panel_size; // irregular pitch, no margins
-  allow_small = !((nrows == 1) || indicator_config_get_single_row (box->config));
+  allow_small = !((nrows == 1) || single_row);
 
   panel_orientation = indicator_config_get_panel_orientation (box->config);
 
@@ -540,6 +564,8 @@ xfce_indicator_box_size_allocate (GtkWidget     *widget,
           width = (is_small) ? size : full_size;
           length = MAX (length,
                         (panel_orientation == GTK_ORIENTATION_HORIZONTAL) ? child_req.width :child_req.height);
+          if (square_icons)
+            length = MAX (length, size);
 
           if (panel_orientation == GTK_ORIENTATION_HORIZONTAL)
             {
