@@ -54,26 +54,26 @@
 static const gchar *pretty_names[][3] =
 {
   /* raw name,                           pretty name,                                 icon-name(?) */
-  { LIBSO("application"),                 N_("Application Indicators"),               "application-default-icon" },
-  { LIBSO("soundmenu"),                   N_("Sound Menu"),                           "preferences-desktop-sound" },
-  { "com.canonical.indicator.sound",     N_("Sound Menu"),                           "preferences-desktop-sound" },
-  { LIBSO("printersmenu"),                N_("Printers Menu"),                        "printer" },
-  { LIBSO("power"),                       N_("Power Management"),                     NULL },
-  { "com.canonical.indicator.power",     N_("Power Management"),                     NULL },
-  { LIBSO("appmenu"),                     N_("Application Menus (Global Menu)"),      "menu-editor" },
-  { LIBSO("session"),                     N_("Session Management"),                   NULL },
-  { "com.canonical.indicator.session",   N_("Session Management"),                   NULL },
-  { LIBSO("messaging"),                   N_("Messaging Menu"),                       "indicator-messages-new" },
-  { "com.canonical.indicator.messages",  N_("Messaging Menu"),                       "indicator-messages-new" },
-  { LIBSO("datetime"),                    N_("Date and Time"),                        "time-admin" },
-  { "com.canonical.indicator.datetime",  N_("Date and Time"),                        "time-admin" },
-  { LIBSO("bluetooth"),                   N_("Bluetooth"),                            "bluetooth-active" },
-  { "com.canonical.indicator.bluetooth", N_("Bluetooth"),                            "bluetooth-active" },
-  { LIBSO("syncindicator"),               N_("Sync Menu"),                            "sync-client-updating" },
-  { "com.canonical.indicator.keyboard",  N_("Keyboard"),                             NULL },
-  { "com.canonical.indicator.location",  N_("Location"),                             NULL },
-  { "com.canonical.indicator.network",   N_("Network"),                              NULL },
-  { LIBSO("workrave"),                    N_("Workrave"),                             "workrave" },
+  { LIBSO("ayatana-application"),        N_("Application Indicators"),               "application-default-icon" },
+  { LIBSO("ayatana-soundmenu"),          N_("Sound Menu"),                           "preferences-desktop-sound" },
+  { "org.ayatana.indicator.sound",       N_("Sound Menu"),                           "preferences-desktop-sound" },
+  { LIBSO("ayatana-printersmenu"),       N_("Printers Menu"),                        "printer" },
+  { LIBSO("ayatana-power"),              N_("Power Management"),                     NULL },
+  { "org.ayatana.indicator.power",       N_("Power Management"),                     NULL },
+  { LIBSO("ayatana-appmenu"),            N_("Application Menus (Global Menu)"),      "menu-editor" },
+  { LIBSO("ayatana-session"),            N_("Session Management"),                   NULL },
+  { "org.ayatana.indicator.session",     N_("Session Management"),                   NULL },
+  { LIBSO("ayatana-messaging"),          N_("Messaging Menu"),                       "indicator-messages-new" },
+  { "org.ayatana.indicator.messages",    N_("Messaging Menu"),                       "indicator-messages-new" },
+  { LIBSO("ayatana-datetime"),           N_("Date and Time"),                        "time-admin" },
+  { "org.ayatana.indicator.datetime",    N_("Date and Time"),                        "time-admin" },
+  { LIBSO("ayatana-bluetooth"),          N_("Bluetooth"),                            "bluetooth-active" },
+  { "org.ayatana.indicator.bluetooth",   N_("Bluetooth"),                            "bluetooth-active" },
+  { LIBSO("ayatana-syncindicator"),      N_("Sync Menu"),                            "sync-client-updating" },
+  { "org.ayatana.indicator.keyboard",    N_("Keyboard"),                             NULL },
+  { "org.ayatana.indicator.location",    N_("Location"),                             NULL },
+  { "org.ayatana.indicator.network",     N_("Network"),                              NULL },
+  { LIBSO("ayatana-workrave"),           N_("Workrave"),                             "workrave" },
 };
 
 
@@ -443,7 +443,7 @@ indicator_dialog_clear_clicked (GtkWidget       *button,
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   if (xfce_dialog_confirm (GTK_WINDOW (gtk_widget_get_toplevel (button)),
-                           "gtk-clear", NULL, NULL,
+                           "edit-clear", _("Clear"), NULL,
                            _("Are you sure you want to clear the list of "
                              "known indicators?")))
     {
@@ -495,16 +495,18 @@ indicator_dialog_build (IndicatorDialog *dialog)
 
       object = gtk_builder_get_object (builder, "checkbutton-align-left");
       g_return_if_fail (GTK_IS_WIDGET (object));
-      //exo_mutual_binding_new (G_OBJECT (dialog->config), "align-left",
-      //                        G_OBJECT (object), "active");
       g_object_bind_property (G_OBJECT (dialog->config), "align-left",
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
+      object = gtk_builder_get_object (builder, "checkbutton-square-icons");
+      g_return_if_fail (GTK_IS_WIDGET (object));
+      g_object_bind_property (G_OBJECT (dialog->config), "square-icons",
+                              G_OBJECT (object), "active",
+                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
       object = gtk_builder_get_object (builder, "checkbutton-whitelist");
       g_return_if_fail (GTK_IS_WIDGET (object));
-      //exo_mutual_binding_new (G_OBJECT (dialog->config), "mode-whitelist",
-      //                        G_OBJECT (object), "active");
       g_object_bind_property (G_OBJECT (dialog->config), "mode-whitelist",
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -547,7 +549,7 @@ indicator_dialog_build (IndicatorDialog *dialog)
     }
   else
     {
-      g_critical ("Faild to construct the builder: %s.",
+      g_critical ("Failed to construct the builder: %s.",
                   error->message);
       g_error_free (error);
     }
